@@ -1,12 +1,15 @@
 /**
- * Copyright (C) 2019-2021  The Software Heritage developers
+ * Copyright (C) 2019-2022  The Software Heritage developers
  * See the AUTHORS file at the top-level directory of this distribution
  * License: GNU Affero General Public License version 3, or any later version
  * See top-level LICENSE file for more information
  */
 
 let url;
-let origin;
+const origin = {
+  type: 'git',
+  url: 'https://git.example.org/user/repo'
+};
 const $ = Cypress.$;
 
 const saveCodeMsg = {
@@ -19,8 +22,8 @@ const saveCodeMsg = {
   'csrfError': 'CSRF Failed: Referrer checking failed - no Referrer.'
 };
 
-const anonymousVisitTypes = ['cvs', 'git', 'hg', 'svn'];
-const allVisitTypes = ['archives', 'cvs', 'git', 'hg', 'svn'];
+const anonymousVisitTypes = ['bzr', 'cvs', 'git', 'hg', 'svn'];
+const allVisitTypes = ['archives', 'bzr', 'cvs', 'git', 'hg', 'svn'];
 
 function makeOriginSaveRequest(originType, originUrl) {
   cy.get('#swh-input-origin-url')
@@ -98,7 +101,6 @@ function genOriginSaveResponse({
 describe('Origin Save Tests', function() {
   before(function() {
     url = this.Urls.origin_save();
-    origin = this.origin[0];
     this.originSaveUrl = this.Urls.api_1_save_origin(origin.type, origin.url);
   });
 
@@ -731,7 +733,9 @@ describe('Origin Save Tests', function() {
 
     for (const originUrl of ['https://github.com/BiC-MnI/MnI_AuToReG',
                              'https://github.com/BiC-MnI/MnI_AuToReG.git',
-                             'https://github.com/BiC-MnI/MnI_AuToReG/']) {
+                             'https://github.com/BiC-MnI/MnI_AuToReG/',
+                             'https://BiC-MnI.github.io/MnI_AuToReG/'
+    ]) {
 
       // enter non canonical URL of github repo
       cy.get('#swh-input-origin-url')
@@ -751,4 +755,26 @@ describe('Origin Save Tests', function() {
 
   });
 
+  it('should switch tabs when playing with browser history', function() {
+    cy.intercept('/save/requests/list/**', {fixture: 'origin-save'});
+    cy.intercept('/save/task/info/**', {fixture: 'save-task-info'});
+
+    cy.get('#swh-origin-save-request-help-tab')
+      .should('have.class', 'active');
+
+    cy.get('#swh-origin-save-requests-list-tab')
+      .click();
+
+    cy.get('#swh-origin-save-requests-list-tab')
+      .should('have.class', 'active');
+
+    cy.go('back')
+      .get('#swh-origin-save-request-help-tab')
+      .should('have.class', 'active');
+
+    cy.go('forward')
+      .get('#swh-origin-save-requests-list-tab')
+      .should('have.class', 'active');
+  });
+
 });
