@@ -215,7 +215,7 @@ describe('Test origin-search', function() {
       .as('searchOrigin');
 
     cy.get('#swh-origins-url-patterns')
-      .type(origin.url.slice(0, -1));
+      .type(origin.url.slice(0, -1), {delay: 0, force: true});
 
     cy.get('.swh-search-icon')
       .click();
@@ -237,6 +237,80 @@ describe('Test origin-search', function() {
       .should('exist');
   });
 
+  it('should show error messages when using the query language', function() {
+    cy.adminLogin();
+    cy.visit(url);
+
+    cy.intercept('GET', `${this.Urls.api_1_origin_search('**')}**`,
+                 {
+                   body: {
+                     'exception': 'BadInputExc',
+                     'reason': 'Syntax error in search query: Invalid query'
+                   },
+                   statusCode: 400
+                 })
+      .as('searchOrigin');
+
+    cy.get('#swh-search-use-ql')
+      .should('exist')
+      .click({force: true}); // Covered by label
+
+    cy.get('#swh-origins-url-patterns')
+      .type('this is not a valid query')
+      .type('{enter}');
+
+    cy.wait('@searchOrigin').then((xhr) => {
+      cy.get('#swh-no-result')
+        .should('contain', 'Syntax error in search query');
+    });
+
+  });
+
+  function checkSearchHasResults() {
+    cy.get('.swh-search-icon')
+        .click();
+
+    cy.wait('@checkOriginVisits');
+
+    cy.get('#origin-search-results')
+        .should('be.visible');
+
+    cy.get('tbody tr td.swh-origin-visit-type')
+      .should('exist');
+  }
+
+  it('should search all origins when no pattern is provided', function() {
+    cy.intercept('**/visit/latest/**').as('checkOriginVisits');
+
+    // with default filters
+    checkSearchHasResults();
+
+    // remove filters
+    cy.get('#swh-search-origins-with-visit')
+      .uncheck({force: true})
+      .get('#swh-filter-empty-visits')
+      .uncheck({force: true});
+    checkSearchHasResults();
+
+  });
+
+  it('should search all origins for a visit type', function() {
+    cy.intercept('**/visit/latest/**').as('checkOriginVisits');
+
+    for (const visitType of ['git', 'tar']) {
+      cy.get('#swh-search-visit-type')
+        .select(visitType);
+
+      checkSearchHasResults();
+
+      cy.get('tbody tr td.swh-origin-visit-type').then(elts => {
+        for (const elt of elts) {
+          cy.get(elt).should('have.text', visitType);
+        }
+      });
+    }
+  });
+
   context('Test pagination', function() {
     it('should not paginate if there are not many results', function() {
       // Setup search
@@ -493,7 +567,7 @@ describe('Test origin-search', function() {
         .as('searchOrigin');
 
       cy.get('#swh-origins-url-patterns')
-        .type(swhid);
+        .type(swhid, {delay: 0, force: true});
 
       cy.get('.swh-search-icon')
         .click();
