@@ -5,7 +5,7 @@
  * See top-level LICENSE file for more information
  */
 
-import {handleFetchError, isArchivedOrigin} from 'utils/functions';
+import {handleFetchError, errorMessageFromResponse, isArchivedOrigin} from 'utils/functions';
 
 const limit = 100;
 const linksPrev = [];
@@ -109,7 +109,9 @@ function searchOriginsFirst(searchQueryText, limit) {
     baseSearchUrl = new URL(Urls.api_1_origin_metadata_search(), window.location);
     baseSearchUrl.searchParams.append('fulltext', searchQueryText);
   } else {
+    const useSearchQL = $('#swh-search-use-ql').prop('checked');
     baseSearchUrl = new URL(Urls.api_1_origin_search(searchQueryText), window.location);
+    baseSearchUrl.searchParams.append('use_ql', useSearchQL ?? false);
   }
 
   const withVisit = $('#swh-search-origins-with-visit').prop('checked');
@@ -145,11 +147,13 @@ async function searchOrigins(searchUrl) {
 
     $('.swh-loading').removeClass('show');
     populateOriginSearchResultsTable(data);
-  } catch (response) {
+  } catch (errorResponse) {
+    const errorData = await errorResponse.json();
     $('.swh-loading').removeClass('show');
     inSearch = false;
     $('#swh-origin-search-results').hide();
-    $('#swh-no-result').text(`Error ${response.status}: ${response.statusText}`);
+    $('#swh-no-result').text(errorMessageFromResponse(
+      errorData, 'An unknown error occurred while searching origins'));
     $('#swh-no-result').show();
   }
 }
@@ -198,6 +202,7 @@ export function initOriginSearch() {
         const searchQueryText = $('#swh-origins-url-patterns').val().trim();
         const withVisit = $('#swh-search-origins-with-visit').prop('checked');
         const withContent = $('#swh-filter-empty-visits').prop('checked');
+        const useSearchQL = $('#swh-search-use-ql').prop('checked');
         const searchMetadata = $('#swh-search-origin-metadata').prop('checked');
         const visitType = $('#swh-search-visit-type').val();
         const queryParameters = new URLSearchParams();
@@ -208,6 +213,9 @@ export function initOriginSearch() {
         if (withContent) {
           queryParameters.append('with_content', withContent);
         }
+        if (useSearchQL) {
+          queryParameters.append('use_ql', useSearchQL ?? false);
+        }
         if (searchMetadata) {
           queryParameters.append('search_metadata', searchMetadata);
         }
@@ -240,15 +248,18 @@ export function initOriginSearch() {
       event.preventDefault();
     });
 
-    const urlParams = new URLSearchParams(window.location.search);
-    const query = urlParams.get('q');
-    const withVisit = urlParams.has('with_visit');
-    const withContent = urlParams.has('with_content');
-    const searchMetadata = urlParams.has('search_metadata');
-    const visitType = urlParams.get('visit_type');
-    if (query) {
+    if (window.location.search) {
+      const urlParams = new URLSearchParams(window.location.search);
+      const query = urlParams.get('q');
+      const withVisit = urlParams.has('with_visit');
+      const useSearchQL = urlParams.has('use_ql');
+      const withContent = urlParams.has('with_content');
+      const searchMetadata = urlParams.has('search_metadata');
+      const visitType = urlParams.get('visit_type');
+
       $('#swh-origins-url-patterns').val(query);
       $('#swh-search-origins-with-visit').prop('checked', withVisit);
+      $('#swh-search-use-ql').prop('checked', useSearchQL ?? false);
       $('#swh-filter-empty-visits').prop('checked', withContent);
       $('#swh-search-origin-metadata').prop('checked', searchMetadata);
       if (visitType) {
