@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,8 +6,6 @@
 import difflib
 from distutils.util import strtobool
 
-import sentry_sdk
-
 from django.http import HttpResponse, JsonResponse
 from django.shortcuts import redirect, render
 
@@ -22,7 +20,12 @@ from swh.web.browse.utils import (
     request_content,
 )
 from swh.web.common import archive, highlightjs, query
-from swh.web.common.exc import BadInputExc, NotFoundExc, http_status_code_message
+from swh.web.common.exc import (
+    BadInputExc,
+    NotFoundExc,
+    http_status_code_message,
+    sentry_capture_exception,
+)
 from swh.web.common.identifiers import get_swhids_info
 from swh.web.common.typing import ContentMetadata, SWHObjectInfo
 from swh.web.common.utils import gen_path_info, reverse, swh_object_icons
@@ -67,7 +70,7 @@ _auto_diff_size_limit = 20000
 
 
 @browse_route(
-    r"content/(?P<from_query_string>.*)/diff/(?P<to_query_string>.*)",
+    r"content/(?P<from_query_string>.*)/diff/(?P<to_query_string>.*)/",
     view_name="diff-contents",
 )
 def _contents_diff(request, from_query_string, to_query_string):
@@ -162,7 +165,7 @@ def _contents_diff(request, from_query_string, to_query_string):
                 diff_lines = difflib.unified_diff(content_from_lines, content_to_lines)
                 diff_str = "".join(list(diff_lines)[2:])
         except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+            sentry_capture_exception(exc)
             diff_str = str(exc)
 
     diff_data["diff_str"] = diff_str
@@ -180,12 +183,14 @@ def _get_content_from_request(request):
         raise BadInputExc(
             "The origin_url or snapshot query parameters must be provided."
         )
+
+    visit_id = int(request.GET.get("visit_id", 0))
     snapshot_context = get_snapshot_context(
         snapshot_id=snapshot,
         origin_url=origin_url,
         path=path,
         timestamp=request.GET.get("timestamp"),
-        visit_id=request.GET.get("visit_id"),
+        visit_id=visit_id or None,
         branch_name=request.GET.get("branch"),
         release_name=request.GET.get("release"),
         browse_context="content",
@@ -238,11 +243,12 @@ def content_display(request, query_string=None):
     snapshot_context = None
     if origin_url is not None or snapshot_id is not None:
         try:
+            visit_id = int(request.GET.get("visit_id", 0))
             snapshot_context = get_snapshot_context(
                 origin_url=origin_url,
                 snapshot_id=snapshot_id,
                 timestamp=request.GET.get("timestamp"),
-                visit_id=request.GET.get("visit_id"),
+                visit_id=visit_id or None,
                 branch_name=request.GET.get("branch"),
                 release_name=request.GET.get("release"),
                 revision_id=request.GET.get("revision"),
@@ -335,7 +341,10 @@ def content_display(request, query_string=None):
 
     content_checksums = content_data.get("checksums", {})
 
-    content_url = reverse("browse-content", url_args={"query_string": query_string},)
+    content_url = reverse(
+        "browse-content",
+        url_args={"query_string": query_string},
+    )
 
     content_raw_url = reverse(
         "browse-content-raw",
@@ -402,7 +411,9 @@ def content_display(request, query_string=None):
             )
 
     swhids_info = get_swhids_info(
-        swh_objects, snapshot_context, extra_context=content_metadata,
+        swh_objects,
+        snapshot_context,
+        extra_context=content_metadata,
     )
 
     heading = "Content - %s" % content_checksums.get("sha1_git")
