@@ -1,10 +1,8 @@
-# Copyright (C) 2017-2021  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import sentry_sdk
-
 from django.shortcuts import render
 
 from swh.model.swhids import ObjectType
@@ -19,7 +17,7 @@ from swh.web.browse.utils import (
     gen_revision_link,
 )
 from swh.web.common import archive
-from swh.web.common.exc import NotFoundExc
+from swh.web.common.exc import NotFoundExc, sentry_capture_exception
 from swh.web.common.identifiers import get_swhids_info
 from swh.web.common.typing import ReleaseMetadata, SWHObjectInfo
 from swh.web.common.utils import format_utc_iso_date, reverse
@@ -47,14 +45,14 @@ def release_browse(request, sha1_git):
     if not origin_url:
         origin_url = request.GET.get("origin")
     timestamp = request.GET.get("timestamp")
-    visit_id = request.GET.get("visit_id")
+    visit_id = int(request.GET.get("visit_id", 0))
     if origin_url:
         try:
             snapshot_context = get_snapshot_context(
                 snapshot_id,
                 origin_url,
                 timestamp,
-                visit_id,
+                visit_id or None,
                 release_name=release["name"],
             )
         except NotFoundExc as e:
@@ -132,7 +130,7 @@ def release_browse(request, sha1_git):
                 SWHObjectInfo(object_type=ObjectType.DIRECTORY, object_id=rev_directory)
             )
         except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+            sentry_capture_exception(exc)
     elif release["target_type"] == ObjectType.DIRECTORY.name.lower():
         target_link = gen_directory_link(
             release["target"],
@@ -155,7 +153,7 @@ def release_browse(request, sha1_git):
                 )
             )
         except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+            sentry_capture_exception(exc)
     elif release["target_type"] == ObjectType.CONTENT.name.lower():
         target_link = gen_content_link(
             release["target"],
