@@ -8,4 +8,4 @@ from django.apps import AppConfig
 
 class SwhWebCommonConfig(AppConfig):
     name = "swh.web.common"
-    label = "swh.web.common"
+    label = "swh_web_common"
