@@ -1,9 +1,8 @@
-# Copyright (C) 2018-2021  The Software Heritage developers
+# Copyright (C) 2018-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-from bisect import bisect_right
 from datetime import datetime, timedelta, timezone
 from functools import lru_cache
 from itertools import product
@@ -13,7 +12,6 @@ from typing import Any, Dict, List, Optional, Tuple
 
 from prometheus_client import Gauge
 import requests
-import sentry_sdk
 
 from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.core.validators import URLValidator
@@ -22,7 +20,12 @@ from django.utils.html import escape
 
 from swh.scheduler.utils import create_oneshot_task_dict
 from swh.web.common import archive
-from swh.web.common.exc import BadInputExc, ForbiddenExc, NotFoundExc
+from swh.web.common.exc import (
+    BadInputExc,
+    ForbiddenExc,
+    NotFoundExc,
+    sentry_capture_exception,
+)
 from swh.web.common.models import (
     SAVE_REQUEST_ACCEPTED,
     SAVE_REQUEST_PENDING,
@@ -39,12 +42,7 @@ from swh.web.common.models import (
     SaveOriginRequest,
     SaveUnauthorizedOrigin,
 )
-from swh.web.common.origin_visits import get_origin_visits
-from swh.web.common.typing import (
-    OriginExistenceCheckInfo,
-    OriginInfo,
-    SaveOriginRequestInfo,
-)
+from swh.web.common.typing import OriginExistenceCheckInfo, SaveOriginRequestInfo
 from swh.web.common.utils import SWH_WEB_METRICS_REGISTRY, parse_iso8601_date_to_utc
 from swh.web.config import get_config, scheduler
 
@@ -126,8 +124,10 @@ _visit_type_task = {
     "hg": "load-hg",
     "svn": "load-svn",
     "cvs": "load-cvs",
+    "bzr": "load-bzr",
 }
 
+
 _visit_type_task_privileged = {
     "archives": "load-archive-files",
 }
@@ -209,7 +209,7 @@ def _check_visit_type_savable(visit_type: str, privileged_user: bool = False) ->
 
 
 _validate_url = URLValidator(
-    schemes=["http", "https", "svn", "git", "rsync", "pserver", "ssh"]
+    schemes=["http", "https", "svn", "git", "rsync", "pserver", "ssh", "bzr"]
 )
 
 
@@ -285,16 +285,11 @@ def _get_visit_info_for_save_request(
     # as those requests to storage are expensive and associated loading task
     # surely ended up with errors
     if time_delta.days <= MAX_THRESHOLD_DAYS:
-        try:
-            origin_info = archive.lookup_origin(OriginInfo(url=save_request.origin_url))
-            origin_visits = get_origin_visits(origin_info)
-            visit_dates = [parse_iso8601_date_to_utc(v["date"]) for v in origin_visits]
-            i = bisect_right(visit_dates, save_request.request_date)
-            if i != len(visit_dates):
-                visit_date = visit_dates[i]
-                visit_status = origin_visits[i]["status"]
-        except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+        origin = save_request.origin_url
+        ovs = archive.origin_visit_find_by_date(origin, save_request.request_date)
+        if ovs:
+            visit_date = parse_iso8601_date_to_utc(ovs["date"])
+            visit_status = ovs["status"]
     return visit_date, visit_status
 
 
@@ -332,7 +327,8 @@ def _check_visit_update_status(
 
 
 def _compute_task_loading_status(
-    task: Optional[Dict[str, Any]] = None, task_run: Optional[Dict[str, Any]] = None,
+    task: Optional[Dict[str, Any]] = None,
+    task_run: Optional[Dict[str, Any]] = None,
 ) -> Optional[str]:
     loading_task_status: Optional[str] = None
     # First determine the loading task status out of task information
@@ -408,7 +404,7 @@ def create_save_origin_request(
 ) -> SaveOriginRequestInfo:
     """Create a loading task to save a software origin into the archive.
 
-    This function aims to create a software origin loading task trough the use of the
+    This function aims to create a software origin loading task through the use of the
     swh-scheduler component.
 
     First, some checks are performed to see if the visit type and origin url are valid
@@ -621,7 +617,9 @@ def update_save_origin_requests_from_queryset(
             task_runs = {}
         for sor in requests_queryset:
             sr_dict = _update_save_request_info(
-                sor, tasks.get(sor.loading_task_id), task_runs.get(sor.loading_task_id),
+                sor,
+                tasks.get(sor.loading_task_id),
+                task_runs.get(sor.loading_task_id),
             )
             save_requests.append(sr_dict)
     return save_requests
@@ -816,7 +814,7 @@ def get_save_origin_task_info(
 
     except Exception as exc:
         logger.warning("Request to Elasticsearch failed\n%s", exc)
-        sentry_sdk.capture_exception(exc)
+        sentry_capture_exception(exc)
 
     if not full_info:
         for field in ("id", "backend_id", "worker"):
@@ -916,7 +914,8 @@ def compute_save_requests_metrics() -> None:
     for sor in SaveOriginRequest.objects.all():
         if sor.status == SAVE_REQUEST_ACCEPTED:
             _accepted_save_requests_gauge.labels(
-                load_task_status=sor.loading_task_status, visit_type=sor.visit_type,
+                load_task_status=sor.loading_task_status,
+                visit_type=sor.visit_type,
             ).inc()
 
         _submitted_save_requests_gauge.labels(
@@ -930,5 +929,6 @@ def compute_save_requests_metrics() -> None:
         ):
             delay = sor.visit_date.timestamp() - sor.request_date.timestamp()
             _accepted_save_requests_delay_gauge.labels(
-                load_task_status=sor.loading_task_status, visit_type=sor.visit_type,
+                load_task_status=sor.loading_task_status,
+                visit_type=sor.visit_type,
             ).inc(delay)
