@@ -1,9 +1,8 @@
-# Copyright (C) 2018-2019  The Software Heritage developers
+# Copyright (C) 2018-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
-import math
 from typing import List, Optional
 
 from django.core.cache import cache
@@ -42,40 +41,42 @@ def get_origin_visits(origin_info: OriginInfo) -> List[OriginVisitInfo]:
     cache_entry_id = "origin_visits_%s" % origin_url
     cache_entry = cache.get(cache_entry_id)
 
+    last_visit = 0
+    origin_visits = []
+    new_visits = []
+    per_page = archive.MAX_LIMIT
     if cache_entry:
+        origin_visits = cache_entry
         last_visit = cache_entry[-1]["visit"]
         new_visits = list(
-            archive.lookup_origin_visits(origin_url, last_visit=last_visit)
+            archive.lookup_origin_visits(
+                origin_url, last_visit=last_visit, per_page=per_page
+            )
         )
+        last_visit += len(new_visits)
         if not new_visits:
             last_snp = archive.lookup_latest_origin_snapshot(origin_url)
             if not last_snp or last_snp["id"] == cache_entry[-1]["snapshot"]:
                 return cache_entry
 
-    origin_visits = []
-
-    per_page = archive.MAX_LIMIT
-    last_visit = None
+    # get new visits that we did not retrieve yet
     while 1:
         visits = list(
             archive.lookup_origin_visits(
                 origin_url, last_visit=last_visit, per_page=per_page
             )
         )
-        origin_visits += visits
+        new_visits += visits
         if len(visits) < per_page:
             break
-        else:
-            if not last_visit:
-                last_visit = per_page
-            else:
-                last_visit += per_page
+        last_visit += per_page
 
     def _visit_sort_key(visit):
         ts = parse_iso8601_date_to_utc(visit["date"]).timestamp()
         return ts + (float(visit["visit"]) / 10e3)
 
-    origin_visits = sorted(origin_visits, key=lambda v: _visit_sort_key(v))
+    # cache entry is already sorted with oldest visits
+    origin_visits += sorted(new_visits, key=lambda v: _visit_sort_key(v))
 
     cache.set(cache_entry_id, origin_visits)
 
@@ -134,6 +135,25 @@ def get_origin_visit(
     if visit and (visit["snapshot"] == snapshot_id or visit["visit"] == visit_id):
         return visit
 
+    if visit_id:
+        return archive.lookup_origin_visit(origin_info["url"], visit_id)
+
+    if visit_ts:
+        visit = archive.origin_visit_find_by_date(
+            origin_info["url"],
+            parse_iso8601_date_to_utc(visit_ts),
+            greater_or_equal=False,
+        )
+        if visit is not None:
+            return visit
+        else:
+            raise NotFoundExc(
+                (
+                    "Visit with timestamp %s for origin with "
+                    "url %s not found!" % (visit_ts, origin_info["url"])
+                )
+            )
+
     visits = get_origin_visits(origin_info)
 
     if not visits:
@@ -152,46 +172,4 @@ def get_origin_visit(
             )
         return visits[0]
 
-    if visit_id:
-        visits = [v for v in visits if v["visit"] == int(visit_id)]
-        if len(visits) == 0:
-            raise NotFoundExc(
-                (
-                    "Visit with id %s for origin with"
-                    " url %s not found!" % (visit_id, origin_info["url"])
-                )
-            )
-        return visits[0]
-
-    if visit_ts:
-
-        target_visit_ts = math.floor(parse_iso8601_date_to_utc(visit_ts).timestamp())
-
-        # Find the visit with date closest to the target (in absolute value)
-        (abs_time_delta, visit_idx) = min(
-            (
-                (math.floor(parse_iso8601_date_to_utc(visit["date"]).timestamp()), i)
-                for (i, visit) in enumerate(visits)
-            ),
-            key=lambda ts_and_i: abs(ts_and_i[0] - target_visit_ts),
-        )
-
-        if visit_idx is not None:
-            visit = visits[visit_idx]
-            # If multiple visits have the same date, select the one with
-            # the largest id.
-            while (
-                visit_idx < len(visits) - 1
-                and visit["date"] == visits[visit_idx + 1]["date"]
-            ):
-                visit_idx = visit_idx + 1
-                visit = visits[visit_idx]
-            return visit
-        else:
-            raise NotFoundExc(
-                (
-                    "Visit with timestamp %s for origin with "
-                    "url %s not found!" % (visit_ts, origin_info["url"])
-                )
-            )
     return visits[-1]
