@@ -1,12 +1,13 @@
-# Copyright (C) 2017-2021  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 from datetime import datetime, timezone
+import functools
 import os
 import re
-from typing import Any, Dict, List, Optional
+from typing import Any, Callable, Dict, List, Optional
 import urllib.parse
 
 from bs4 import BeautifulSoup
@@ -21,18 +22,25 @@ import requests
 from requests.auth import HTTPBasicAuth
 
 from django.core.cache import cache
+from django.core.cache.backends.base import DEFAULT_TIMEOUT
 from django.http import HttpRequest, QueryDict
 from django.shortcuts import redirect
 from django.urls import resolve
 from django.urls import reverse as django_reverse
 
-from swh.web.auth.utils import ADMIN_LIST_DEPOSIT_PERMISSION
-from swh.web.common.exc import BadInputExc
+from swh.web.auth.utils import (
+    ADD_FORGE_MODERATOR_PERMISSION,
+    ADMIN_LIST_DEPOSIT_PERMISSION,
+    MAILMAP_ADMIN_PERMISSION,
+)
+from swh.web.common.exc import BadInputExc, sentry_capture_exception
 from swh.web.common.typing import QueryParameters
-from swh.web.config import get_config, search
+from swh.web.config import SWH_WEB_SERVER_NAME, get_config, search
 
 SWH_WEB_METRICS_REGISTRY = CollectorRegistry(auto_describe=True)
 
+SWHID_RE = "swh:1:[a-z]{3}:[0-9a-z]{40}"
+
 swh_object_icons = {
     "alias": "mdi mdi-star",
     "branch": "mdi mdi-source-branch",
@@ -150,7 +158,7 @@ def shorten_path(path):
     return re.sub(sha1_re, r"\1...", ret)
 
 
-def format_utc_iso_date(iso_date, fmt="%d %B %Y, %H:%M UTC"):
+def format_utc_iso_date(iso_date, fmt="%d %B %Y, %H:%M:%S UTC"):
     """Turns a string representation of an ISO 8601 datetime string
     to UTC and format it into a more human readable one.
 
@@ -242,6 +250,28 @@ def get_client_ip(request):
     return ip
 
 
+def is_swh_web_development(request: HttpRequest) -> bool:
+    """Indicate if we are running a development version of swh-web."""
+    site_base_url = request.build_absolute_uri("/")
+    return any(
+        host in site_base_url for host in ("localhost", "127.0.0.1", "testserver")
+    )
+
+
+def is_swh_web_staging(request: HttpRequest) -> bool:
+    """Indicate if we are running a staging version of swh-web."""
+    config = get_config()
+    site_base_url = request.build_absolute_uri("/")
+    return any(
+        server_name in site_base_url for server_name in config["staging_server_names"]
+    )
+
+
+def is_swh_web_production(request: HttpRequest) -> bool:
+    """Indicate if we are running the public production version of swh-web."""
+    return SWH_WEB_SERVER_NAME in request.build_absolute_uri("/")
+
+
 browsers_supported_image_mimes = set(
     [
         "image/gif",
@@ -269,7 +299,7 @@ def context_processor(request):
         # To avoid django.template.base.VariableDoesNotExist errors
         # when rendering templates when standard Django user is logged in.
         request.user.backend = "django.contrib.auth.backends.ModelBackend"
-    site_base_url = request.build_absolute_uri("/")
+
     return {
         "swh_object_icons": swh_object_icons,
         "available_languages": None,
@@ -277,19 +307,17 @@ def context_processor(request):
         "oidc_enabled": bool(config["keycloak"]["server_url"]),
         "browsers_supported_image_mimes": browsers_supported_image_mimes,
         "keycloak": config["keycloak"],
-        "site_base_url": site_base_url,
+        "site_base_url": request.build_absolute_uri("/"),
         "DJANGO_SETTINGS_MODULE": os.environ["DJANGO_SETTINGS_MODULE"],
         "status": config["status"],
-        "swh_web_dev": "localhost" in site_base_url,
-        "swh_web_staging": any(
-            [
-                server_name in site_base_url
-                for server_name in config["staging_server_names"]
-            ]
-        ),
+        "swh_web_dev": is_swh_web_development(request),
+        "swh_web_staging": is_swh_web_staging(request),
         "swh_web_version": get_distribution("swh.web").version,
         "iframe_mode": False,
         "ADMIN_LIST_DEPOSIT_PERMISSION": ADMIN_LIST_DEPOSIT_PERMISSION,
+        "ADD_FORGE_MODERATOR_PERMISSION": ADD_FORGE_MODERATOR_PERMISSION,
+        "FEATURES": get_config()["features"],
+        "MAILMAP_ADMIN_PERMISSION": MAILMAP_ADMIN_PERMISSION,
     }
 
 
@@ -352,6 +380,8 @@ def rst_to_html(rst: str) -> str:
         "initial_header_level": 2,
         "halt_level": 4,
         "traceback": True,
+        "file_insertion_enabled": False,
+        "raw_enabled": False,
     }
     pp = publish_parts(rst, writer=_HTML_WRITER, settings_overrides=settings)
     return f'<div class="swh-rst">{pp["html_body"]}</div>'
@@ -370,6 +400,55 @@ def prettify_html(html: str) -> str:
     return BeautifulSoup(html, "lxml").prettify()
 
 
+def django_cache(
+    timeout: int = DEFAULT_TIMEOUT,
+    catch_exception: bool = False,
+    exception_return_value: Any = None,
+    invalidate_cache_pred: Callable[[Any], bool] = lambda val: False,
+):
+    """Decorator to put the result of a function call in Django cache,
+    subsequent calls will directly return the cached value.
+
+    Args:
+        timeout: The number of seconds value will be hold in cache
+        catch_exception: If :const:`True`, any thrown exception by
+            the decorated function will be caught and not reraised
+        exception_return_value: The value to return if previous
+            parameter is set to :const:`True`
+        invalidate_cache_pred: A predicate function enabling to
+            invalidate the cache under certain conditions, decorated
+            function will then be called again
+
+    Returns:
+        The returned value of the decorated function for the specified
+        parameters
+
+    """
+
+    def inner(func):
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            func_args = args + (0,) + tuple(sorted(kwargs.items()))
+            cache_key = str(hash((func.__module__, func.__name__) + func_args))
+            ret = cache.get(cache_key)
+            if ret is None or invalidate_cache_pred(ret):
+                try:
+                    ret = func(*args, **kwargs)
+                except Exception as exc:
+                    if catch_exception:
+                        sentry_capture_exception(exc)
+                        return exception_return_value
+                    else:
+                        raise
+                else:
+                    cache.set(cache_key, ret, timeout=timeout)
+            return ret
+
+        return wrapper
+
+    return inner
+
+
 def _deposits_list_url(
     deposits_list_base_url: str, page_size: int, username: Optional[str]
 ) -> str:
@@ -380,10 +459,10 @@ def _deposits_list_url(
 
 
 def get_deposits_list(username: Optional[str] = None) -> List[Dict[str, Any]]:
-    """Return the list of software deposits using swh-deposit API
-    """
+    """Return the list of software deposits using swh-deposit API"""
     config = get_config()["deposit"]
-    deposits_list_base_url = config["private_api_url"] + "deposits"
+    private_api_url = config["private_api_url"].rstrip("/") + "/"
+    deposits_list_base_url = private_api_url + "deposits"
     deposits_list_auth = HTTPBasicAuth(
         config["private_api_user"], config["private_api_password"]
     )
@@ -396,27 +475,35 @@ def get_deposits_list(username: Optional[str] = None) -> List[Dict[str, Any]]:
         deposits_list_url, auth=deposits_list_auth, timeout=30
     ).json()["count"]
 
-    deposits_data = cache.get(f"swh-deposit-list-{username}")
-    if not deposits_data or deposits_data["count"] != nb_deposits:
+    @django_cache(invalidate_cache_pred=lambda data: data["count"] != nb_deposits)
+    def _get_deposits_data():
         deposits_list_url = _deposits_list_url(
             deposits_list_base_url, page_size=nb_deposits, username=username
         )
-        deposits_data = requests.get(
-            deposits_list_url, auth=deposits_list_auth, timeout=30,
+        return requests.get(
+            deposits_list_url,
+            auth=deposits_list_auth,
+            timeout=30,
         ).json()
-        cache.set(f"swh-deposit-list-{username}", deposits_data)
+
+    deposits_data = _get_deposits_data()
 
     return deposits_data["results"]
 
 
+_origin_visit_types_cache_timeout = 24 * 60 * 60  # 24 hours
+
+
+@django_cache(
+    timeout=_origin_visit_types_cache_timeout,
+    catch_exception=True,
+    exception_return_value=[],
+)
 def origin_visit_types() -> List[str]:
     """Return the exhaustive list of visit types for origins
     ingested into the archive.
     """
-    try:
-        return sorted(search().visit_types_count().keys())
-    except Exception:
-        return []
+    return sorted(search().visit_types_count().keys())
 
 
 def redirect_to_new_route(request, new_route, permanent=True):
@@ -426,4 +513,17 @@ def redirect_to_new_route(request, new_route, permanent=True):
     """
     request_path = resolve(request.path_info)
     args = {**request_path.kwargs, **request.GET.dict()}
-    return redirect(reverse(new_route, query_params=args), permanent=permanent,)
+    return redirect(
+        reverse(new_route, query_params=args),
+        permanent=permanent,
+    )
+
+
+def has_add_forge_now_permission(user) -> bool:
+    """Is a user considered an add-forge-now moderator?
+
+    Returns
+        True if a user is staff or has add forge now moderator permission
+
+    """
+    return user.is_staff or user.has_perm(ADD_FORGE_MODERATOR_PERMISSION)
