@@ -16,10 +16,10 @@ from django.views.decorators.clickjacking import xframe_options_exempt
 
 from swh.scheduler.model import SchedulerMetrics
 from swh.web.common import archive
-from swh.web.common.origin_save import get_savable_visit_types
 from swh.web.common.utils import (
     django_cache,
     get_deposits_list,
+    is_swh_web_development,
     is_swh_web_production,
     reverse,
 )
@@ -48,112 +48,164 @@ listed_origins: Dict[str, Any] = {
             "type": "bitbucket",
             "info_url": "https://bitbucket.org",
             "info": "public repositories from Bitbucket",
-            "search_pattern": "https://bitbucket.org/",
+            "search_pattern": {
+                "default": "https://bitbucket.org/",
+            },
         },
         {
             "type": "cgit",
             "info_url": "https://git.zx2c4.com/cgit/about",
             "info": "public repositories from cgit instances",
-            "search_pattern": "cgit",
+            "search_pattern": {
+                "default": "cgit",
+            },
         },
         {
             "type": "CRAN",
             "info_url": "https://cran.r-project.org",
             "info": "source packages from The Comprehensive R Archive Network",
-            "search_pattern": "https://cran.r-project.org/",
+            "search_pattern": {
+                "default": "https://cran.r-project.org/",
+            },
         },
         {
             "type": "debian",
             "info_url": "https://www.debian.org",
             "info": "source packages from Debian and Debian-based distributions",
-            "search_pattern": "deb://",
+            "search_pattern": {
+                "default": "deb://",
+            },
         },
         {
             "type": "gitea",
             "info_url": "https://gitea.io",
             "info": "public repositories from Gitea instances",
-            "search_pattern": "gitea",
+            "search_pattern": {
+                "default": "gitea",
+            },
         },
         {
             "type": "github",
             "info_url": "https://github.com",
             "info": "public repositories from GitHub",
-            "search_pattern": "https://github.com/",
+            "search_pattern": {
+                "default": "https://github.com/",
+            },
         },
         {
             "type": "gitlab",
             "info_url": "https://gitlab.com",
             "info": "public repositories from multiple GitLab instances",
-            "search_pattern": "gitlab",
+            "search_pattern": {
+                "default": "gitlab",
+            },
         },
         {
             "type": "guix",
             "info_url": "https://guix.gnu.org",
             "info": "source code tarballs used to build the Guix package collection",
             "visit_types": ["nixguix"],
-            "search_pattern": "https://guix.gnu.org/sources.json",
+            "search_pattern": {
+                "default": "https://guix.gnu.org/sources.json",
+            },
         },
         {
             "type": "GNU",
             "info_url": "https://www.gnu.org",
             "info": "releases from the GNU project (as of August 2015)",
-            "search_pattern": "gnu",
+            "search_pattern": {
+                "default": "gnu",
+            },
         },
         {
             "type": "heptapod",
             "info_url": "https://heptapod.net/",
             "info": "public repositories from multiple Heptapod instances",
-            "search_pattern": "heptapod",
+            "search_pattern": {
+                "default": "heptapod",
+            },
         },
         {
             "type": "launchpad",
             "info_url": "https://launchpad.net",
             "logo": "img/logos/launchpad.png",
             "info": "public repositories from Launchpad",
-            "search_pattern": "https://git.launchpad.net/",
+            "search_pattern": {
+                "default": "launchpad.net/",
+            },
+        },
+        {
+            "type": "maven",
+            "info_url": "https://maven.apache.org/",
+            "info": "java source packages from maven repositories",
+            "search_pattern": {
+                "default": "maven",
+                "cvs": "",
+                "git": "",
+                "hg": "",
+                "svn": "",
+            },
         },
         {
             "type": "nixos",
             "info_url": "https://nixos.org",
             "info": "source code tarballs used to build the Nix package collection",
             "visit_types": ["nixguix"],
-            "search_pattern": (
-                "https://nix-community.github.io/nixpkgs-swh/sources-unstable.json"
-            ),
+            "search_pattern": {
+                "default": (
+                    "https://nix-community.github.io/nixpkgs-swh/sources-unstable.json"
+                )
+            },
         },
         {
             "type": "npm",
             "info_url": "https://www.npmjs.com",
             "info": "public packages from the package registry for javascript",
-            "search_pattern": "https://www.npmjs.com",
+            "search_pattern": {
+                "default": "https://www.npmjs.com",
+            },
         },
         {
             "type": "opam",
             "info_url": "https://opam.ocaml.org/",
             "info": "public packages from the source-based package manager for OCaml",
-            "search_pattern": "opam+https://opam.ocaml.org/",
+            "search_pattern": {
+                "default": "opam+https://",
+            },
+        },
+        {
+            "type": "Packagist",
+            "info_url": "https://packagist.org/",
+            "info": "source code repositories referenced by The PHP Package Repository",
+            "search_pattern": {
+                "default": "",
+            },
+        },
+        {
+            "type": "phabricator",
+            "info_url": "https://www.phacility.com/phabricator",
+            "info": "public repositories from multiple Phabricator instances",
+            "search_pattern": {
+                "default": "phabricator",
+            },
         },
-        # apart our forge, most phabricator origins have not been archived
-        # while they have been listed so do not display those type of origins
-        # until new listing processes have been executed and origins loaded
-        #
-        # {
-        #     "type": "phabricator",
-        #     "info_url": "https://www.phacility.com/phabricator",
-        #     "info": "public repositories from multiple Phabricator instances",
-        #     "search_pattern": "phabricator",
-        # },
         {
             "type": "pypi",
             "info_url": "https://pypi.org",
             "info": "source packages from the Python Package Index",
-            "search_pattern": "https://pypi.org",
+            "search_pattern": {
+                "default": "https://pypi.org",
+            },
         },
         {
             "type": "sourceforge",
             "info_url": "https://sourceforge.net",
             "info": "public repositories from SourceForge",
-            "search_pattern": "code.sf.net",
+            "search_pattern": {
+                "default": "code.sf.net",
+                "bzr": "bzr.sourceforge.net",
+                "cvs": "cvs.sourceforge.net",
+            },
         },
     ],
 }
@@ -334,23 +386,27 @@ def _search_url(query: str, visit_type: str) -> str:
 def _swh_coverage(request: HttpRequest) -> HttpResponse:
     use_cache = is_swh_web_production(request)
     listers_metrics = _get_listers_metrics(use_cache)
+
     for origins in listed_origins["origins"]:
+        origins["count"] = "0"
         origins["instances"] = {}
         origins_type = origins["type"]
 
         # special processing for nixos/guix origins as there is no
         # scheduler metrics for those
         if origins_type in ("nixos", "guix"):
-            count = _get_nixguix_origins_count(origins["search_pattern"], use_cache)
+            count = _get_nixguix_origins_count(
+                origins["search_pattern"]["default"], use_cache
+            )
 
-            origins["count"] = f"{count:,}" if count else ""
+            origins["count"] = f"{count:,}"
             origins["instances"][origins_type] = {"nixguix": {"count": count}}
 
         if origins_type not in listers_metrics:
             continue
 
         count_total = sum(
-            [metrics.origins_known for _, metrics in listers_metrics[origins_type]]
+            [metrics.origins_enabled for _, metrics in listers_metrics[origins_type]]
         )
         count_never_visited = sum(
             [
@@ -363,13 +419,11 @@ def _swh_coverage(request: HttpRequest) -> HttpResponse:
         origins["count"] = f"{count:,}"
         origins["instances"] = defaultdict(dict)
         for instance, metrics in listers_metrics[origins_type]:
-            # these types are available in staging/docker but not yet in production
-            if (
-                metrics.visit_type in ("bzr", "cvs")
-                and metrics.visit_type not in get_savable_visit_types()
-            ):
+            instance_count = metrics.origins_enabled - metrics.origins_never_visited
+            # no archived origins for that visit type, skip it
+            if instance_count == 0:
                 continue
-            instance_count = metrics.origins_known - metrics.origins_never_visited
+
             origins["instances"][instance].update(
                 {metrics.visit_type: {"count": f"{instance_count:,}"}}
             )
@@ -389,13 +443,23 @@ def _swh_coverage(request: HttpRequest) -> HttpResponse:
         nb_instances = len(instances)
         for instance_name, visit_types in instances.items():
             for visit_type in visit_types:
-                if nb_instances > 1:
+                search_url = ""
+                if visit_type in origins["search_pattern"]:
+                    search_pattern = origins["search_pattern"][visit_type]
+                elif nb_instances > 1:
                     search_pattern = instance_name
                 else:
-                    search_pattern = origins["search_pattern"]
-                search_url = _search_url(search_pattern, visit_type)
+                    search_pattern = origins["search_pattern"]["default"]
+                if search_pattern:
+                    search_url = _search_url(search_pattern, visit_type)
                 visit_types[visit_type]["search_url"] = search_url
 
+    # filter out origin types without archived origins on production and staging
+    if not is_swh_web_development(request):
+        listed_origins["origins"] = list(
+            filter(lambda o: o["count"] != "0", listed_origins["origins"])
+        )
+
     for origins in legacy_origins["origins"]:
         origins["search_urls"] = {}
         for visit_type in origins["visit_types"]:
@@ -406,6 +470,7 @@ def _swh_coverage(request: HttpRequest) -> HttpResponse:
     deposits_counts = _get_deposits_netloc_counts(use_cache)
 
     for origins in deposited_origins["origins"]:
+        origins["count"] = "0"
         if origins["search_pattern"] in deposits_counts:
             origins["count"] = f"{deposits_counts[origins['search_pattern']]:,}"
         origins["search_urls"] = {
