@@ -12,6 +12,7 @@ import pytest
 from swh.indexer.storage.model import OriginIntrinsicMetadataRow
 from swh.model.hashutil import hash_to_bytes
 from swh.model.model import Origin, OriginVisit, OriginVisitStatus
+from swh.search.exc import SearchQuerySyntaxError
 from swh.search.interface import PagedResult
 from swh.storage.exc import StorageAPIError, StorageDBError
 from swh.storage.utils import now
@@ -80,7 +81,13 @@ def test_api_lookup_origin_visits(
         archive_data.origin_add([new_origin])
         for i, visit_date in enumerate(visit_dates):
             origin_visit = archive_data.origin_visit_add(
-                [OriginVisit(origin=new_origin.url, date=visit_date, type="git",)]
+                [
+                    OriginVisit(
+                        origin=new_origin.url,
+                        date=visit_date,
+                        type="git",
+                    )
+                ]
             )[0]
             archive_data.snapshot_add([new_snapshots[i]])
             visit_status = OriginVisitStatus(
@@ -129,7 +136,13 @@ def test_api_lookup_origin_visits_by_id(
         archive_data.origin_add([new_origin])
         for i, visit_date in enumerate(visit_dates):
             origin_visit = archive_data.origin_visit_add(
-                [OriginVisit(origin=new_origin.url, date=visit_date, type="git",)]
+                [
+                    OriginVisit(
+                        origin=new_origin.url,
+                        date=visit_date,
+                        type="git",
+                    )
+                ]
             )[0]
             archive_data.snapshot_add([new_snapshots[i]])
             visit_status = OriginVisitStatus(
@@ -178,7 +191,13 @@ def test_api_lookup_origin_visit(
         archive_data.origin_add([new_origin])
         for i, visit_date in enumerate(visit_dates):
             origin_visit = archive_data.origin_visit_add(
-                [OriginVisit(origin=new_origin.url, date=visit_date, type="git",)]
+                [
+                    OriginVisit(
+                        origin=new_origin.url,
+                        date=visit_date,
+                        type="git",
+                    )
+                ]
             )[0]
             visit_id = origin_visit.visit
             archive_data.snapshot_add([new_snapshots[i]])
@@ -235,7 +254,13 @@ def test_api_lookup_origin_visit_latest(
         visit_ids = []
         for i, visit_date in enumerate(visit_dates):
             origin_visit = archive_data.origin_visit_add(
-                [OriginVisit(origin=new_origin.url, date=visit_date, type="git",)]
+                [
+                    OriginVisit(
+                        origin=new_origin.url,
+                        date=visit_date,
+                        type="git",
+                    )
+                ]
             )[0]
             visit_ids.append(origin_visit.visit)
 
@@ -283,7 +308,13 @@ def test_api_lookup_origin_visit_latest_with_snapshot(
         visit_ids = []
         for i, visit_date in enumerate(visit_dates):
             origin_visit = archive_data.origin_visit_add(
-                [OriginVisit(origin=new_origin.url, date=visit_date, type="git",)]
+                [
+                    OriginVisit(
+                        origin=new_origin.url,
+                        date=visit_date,
+                        type="git",
+                    )
+                ]
             )[0]
             visit_ids.append(origin_visit.visit)
 
@@ -342,9 +373,7 @@ def test_api_lookup_origin_visit_not_found(api_client, origin):
 
 
 def test_api_origins_wrong_input(api_client, archive_data):
-    """Should fail with 400 if the input is deprecated.
-
-    """
+    """Should fail with 400 if the input is deprecated."""
     # fail if wrong input
     url = reverse("api-1-origins", query_params={"origin_from": 1})
     rv = check_api_get_responses(api_client, url, status_code=400)
@@ -529,7 +558,9 @@ def test_api_origin_search_visit_type(api_client, mocker, backend):
 
     url = reverse(
         "api-1-origin-search",
-        url_args={"url_pattern": "github com",},
+        url_args={
+            "url_pattern": "github com",
+        },
         query_params={"visit_type": "git"},
     )
     rv = check_api_get_responses(api_client, url, status_code=200)
@@ -537,7 +568,9 @@ def test_api_origin_search_visit_type(api_client, mocker, backend):
 
     url = reverse(
         "api-1-origin-search",
-        url_args={"url_pattern": "github com",},
+        url_args={
+            "url_pattern": "github com",
+        },
         query_params={"visit_type": "foo"},
     )
     rv = check_api_get_responses(api_client, url, status_code=200)
@@ -554,10 +587,11 @@ def test_api_origin_search_use_ql(api_client, mocker):
 
     mock_archive_search = mocker.patch("swh.web.common.archive.search")
     mock_archive_search.origin_search.return_value = PagedResult(
-        results=ORIGINS, next_page_token=None,
+        results=ORIGINS,
+        next_page_token=None,
     )
 
-    query = "origin = 'github.com'"
+    query = "origin : 'github.com'"
 
     url = reverse(
         "api-1-origin-search",
@@ -572,6 +606,30 @@ def test_api_origin_search_use_ql(api_client, mocker):
     )
 
 
+def test_api_origin_search_ql_syntax_error(api_client, mocker):
+    mock_archive_search = mocker.patch("swh.web.common.archive.search")
+    mock_archive_search.origin_search.side_effect = SearchQuerySyntaxError(
+        "Invalid syntax"
+    )
+
+    query = "this is not a valid query"
+
+    url = reverse(
+        "api-1-origin-search",
+        url_args={"url_pattern": query},
+        query_params={"visit_type": "git", "use_ql": "true"},
+    )
+    rv = check_api_get_responses(api_client, url, status_code=400)
+    assert rv.data == {
+        "exception": "BadInputExc",
+        "reason": "Syntax error in search query: Invalid syntax",
+    }
+
+    mock_archive_search.origin_search.assert_called_with(
+        query=query, page_token=None, with_visit=False, visit_types=["git"], limit=70
+    )
+
+
 @pytest.mark.parametrize("backend", ["swh-search", "swh-storage"])
 @pytest.mark.parametrize("limit", [1, 2, 3, 10])
 def test_api_origin_search_scroll(api_client, archive_data, mocker, limit, backend):
@@ -735,3 +793,46 @@ def test_api_stat_counters(api_client, mocker, backend):
 
     for obj in ["content", "origin", "release", "directory", "revision"]:
         assert counts.get(obj, 0) > 0
+
+
+@pytest.fixture
+def archived_origins(archive_data):
+    page_result = archive_data.origin_list(page_token=None, limit=10000)
+    origins = [origin.to_dict() for origin in page_result.results]
+    for origin in origins:
+        ovs = archive_data.origin_visit_get_with_statuses(origin["url"]).results
+        del origin["id"]
+        origin["type"] = ovs[0].visit.type
+
+    return origins
+
+
+def test_api_origin_search_empty_pattern(api_client, archived_origins):
+    url = reverse(
+        "api-1-origin-search",
+        url_args={"url_pattern": ""},
+        query_params={"limit": 10000},
+    )
+
+    rv = check_api_get_responses(api_client, url, status_code=200)
+
+    assert {o["url"] for o in rv.data} == {o["url"] for o in archived_origins}
+
+
+def test_api_origin_search_empty_pattern_and_visit_type(api_client, archived_origins):
+
+    visit_types = {o["type"] for o in archived_origins}
+
+    for visit_type in visit_types:
+
+        url = reverse(
+            "api-1-origin-search",
+            url_args={"url_pattern": ""},
+            query_params={"visit_type": visit_type, "limit": 10000},
+        )
+
+        rv = check_api_get_responses(api_client, url, status_code=200)
+
+        assert {o["url"] for o in rv.data} == {
+            o["url"] for o in archived_origins if o["type"] == visit_type
+        }
