@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2019  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -9,7 +9,7 @@ from swh.web.common import highlightjs
 
 def test_get_hljs_language_from_mime_type():
     lang = highlightjs.get_hljs_language_from_mime_type("text/plain")
-    assert lang is None
+    assert lang == "plaintext"
 
     lang = highlightjs.get_hljs_language_from_mime_type("text/x-c")
     assert lang == "c"
@@ -41,6 +41,9 @@ def test_get_hljs_language_from_mime_type():
     lang = highlightjs.get_hljs_language_from_mime_type("text/x-shellscript")
     assert lang == "bash"
 
+    lang = highlightjs.get_hljs_language_from_mime_type("text/html")
+    assert lang == "xml"
+
     lang = highlightjs.get_hljs_language_from_mime_type("image/png")
     assert lang is None
 
@@ -73,6 +76,11 @@ def test_get_hljs_language_from_filename():
         ("foo.jl", "julia"),
         ("Makefile", "makefile"),
         ("CMakeLists.txt", "cmake"),
+        ("robots.txt", "robots-txt"),
     ):
         lang = highlightjs.get_hljs_language_from_filename(filename)
         assert lang == language
+
+    for alias, language in highlightjs._hljs_languages_aliases().items():
+        lang = highlightjs.get_hljs_language_from_filename(f"foo.{alias}")
+        assert lang == language
