@@ -215,9 +215,6 @@ def test_get_save_origin_requests_find_visit_date(mocker, swh_scheduler):
     _fill_scheduler_db(swh_scheduler)
     mock_archive = mocker.patch("swh.web.common.origin_save.archive")
     mock_archive.lookup_origin.return_value = {"url": _origin_url}
-    mock_get_origin_visits = mocker.patch(
-        "swh.web.common.origin_save.get_origin_visits"
-    )
     # create a visit for the save request
     visit_date = datetime.now(tz=timezone.utc).isoformat()
     visit_info = OriginVisitInfo(
@@ -231,18 +228,18 @@ def test_get_save_origin_requests_find_visit_date(mocker, swh_scheduler):
         url="",
         visit=34,
     )
-    mock_get_origin_visits.return_value = [visit_info]
+    mock_archive.origin_visit_find_by_date.return_value = visit_info
 
     # check visit date has been correctly found
     sors = get_save_origin_requests(_visit_type, _origin_url)
     assert len(sors) == 1
     assert sors[0]["save_task_status"] == SAVE_TASK_SUCCEEDED
     assert sors[0]["visit_date"] == visit_date
-    mock_get_origin_visits.assert_called_once()
+    mock_archive.origin_visit_find_by_date.assert_called_once()
 
     # check visit is not searched again when it has been found
     get_save_origin_requests(_visit_type, _origin_url)
-    mock_get_origin_visits.assert_called_once()
+    mock_archive.origin_visit_find_by_date.assert_called_once()
 
     # check visit date are not searched for save requests older than
     # one month
@@ -263,7 +260,7 @@ def test_get_save_origin_requests_find_visit_date(mocker, swh_scheduler):
     assert len(sors) == 2
     assert sors[0]["save_task_status"] == SAVE_TASK_FAILED
     assert sors[0]["visit_date"] is None
-    mock_get_origin_visits.assert_called_once()
+    mock_archive.origin_visit_find_by_date.assert_called_once()
 
 
 def _get_save_origin_requests(
@@ -273,9 +270,7 @@ def _get_save_origin_requests(
     visit_status,
     request_date: Optional[datetime] = None,
 ):
-    """Wrapper around the get_origin_save_origin_request call.
-
-    """
+    """Wrapper around the get_origin_save_origin_request call."""
     SaveOriginRequest.objects.create(
         request_date=datetime.now(tz=timezone.utc),
         visit_type=_visit_type,
@@ -292,9 +287,6 @@ def _get_save_origin_requests(
     )
     mock_archive = mocker.patch("swh.web.common.origin_save.archive")
     mock_archive.lookup_origin.return_value = {"url": _origin_url}
-    mock_get_origin_visits = mocker.patch(
-        "swh.web.common.origin_save.get_origin_visits"
-    )
     # create a visit for the save request with status created
     visit_date = datetime.now(tz=timezone.utc).isoformat()
     visit_info = OriginVisitInfo(
@@ -308,19 +300,17 @@ def _get_save_origin_requests(
         url="",
         visit=34,
     )
-    mock_get_origin_visits.return_value = [visit_info]
+    mock_archive.origin_visit_find_by_date.return_value = visit_info
 
     sors = get_save_origin_requests(_visit_type, _origin_url)
-    mock_get_origin_visits.assert_called_once()
+    mock_archive.origin_visit_find_by_date.assert_called_once()
 
     return sors
 
 
 @pytest.mark.parametrize("visit_date", [None, "some-date"])
 def test_from_save_origin_request_to_save_request_info_dict(visit_date):
-    """Ensure save request to json serializable dict is fine
-
-    """
+    """Ensure save request to json serializable dict is fine"""
     request_date = datetime.now(tz=timezone.utc)
     _visit_date = request_date + timedelta(minutes=5) if visit_date else None
     request_date = datetime.now(tz=timezone.utc)
@@ -377,7 +367,10 @@ def test_origin_exists_404(requests_mock):
 
     actual_result = origin_exists(url_ko)
     assert actual_result == OriginExistenceCheckInfo(
-        origin_url=url_ko, exists=False, last_modified=None, content_length=None,
+        origin_url=url_ko,
+        exists=False,
+        last_modified=None,
+        content_length=None,
     )
 
 
@@ -385,12 +378,16 @@ def test_origin_exists_200_no_data(requests_mock):
     """Existing origin should be reported as such (no extra information)"""
     url = "http://example.org/real-url"
     requests_mock.head(
-        url, status_code=200,
+        url,
+        status_code=200,
     )
 
     actual_result = origin_exists(url)
     assert actual_result == OriginExistenceCheckInfo(
-        origin_url=url, exists=True, last_modified=None, content_length=None,
+        origin_url=url,
+        exists=True,
+        last_modified=None,
+        content_length=None,
     )
 
 
@@ -427,7 +424,11 @@ def test_origin_exists_internet_archive(requests_mock):
         "http://www.cs.unm.edu/~mccune/old-ftp/eqp-09e.tar.gz"
     )
     requests_mock.head(
-        url, status_code=302, headers={"Location": redirect_url,},
+        url,
+        status_code=302,
+        headers={
+            "Location": redirect_url,
+        },
     )
     requests_mock.head(
         redirect_url,
@@ -453,26 +454,40 @@ def test_origin_exists_200_with_data_unexpected_date_format(requests_mock):
     # this is parsable but not as expected
     unexpected_format_date = "Sun, 21 Aug 2021 16:26:32"
     requests_mock.head(
-        url, status_code=200, headers={"last-modified": unexpected_format_date,},
+        url,
+        status_code=200,
+        headers={
+            "last-modified": unexpected_format_date,
+        },
     )
 
     actual_result = origin_exists(url)
     # so the resulting date is None
     assert actual_result == OriginExistenceCheckInfo(
-        origin_url=url, exists=True, content_length=None, last_modified=None,
+        origin_url=url,
+        exists=True,
+        content_length=None,
+        last_modified=None,
     )
 
 
 @pytest.mark.django_db
-@pytest.mark.parametrize("visit_status", [VISIT_STATUS_CREATED, VISIT_STATUS_ONGOING,])
+@pytest.mark.parametrize(
+    "visit_status",
+    [
+        VISIT_STATUS_CREATED,
+        VISIT_STATUS_ONGOING,
+    ],
+)
 def test_get_save_origin_requests_no_visit_date_found(
     mocker, swh_scheduler, visit_status
 ):
-    """Uneventful visits with failed visit status are marked as failed
-
-    """
+    """Uneventful visits with failed visit status are marked as failed"""
     sors = _get_save_origin_requests(
-        mocker, swh_scheduler, load_status="scheduled", visit_status=visit_status,
+        mocker,
+        swh_scheduler,
+        load_status="scheduled",
+        visit_status=visit_status,
     )
     # check no visit date has been found
     assert len(sors) == 1
@@ -482,13 +497,17 @@ def test_get_save_origin_requests_no_visit_date_found(
 
 
 @pytest.mark.django_db
-@pytest.mark.parametrize("visit_status", ["not_found", "failed",])
+@pytest.mark.parametrize(
+    "visit_status",
+    [
+        "not_found",
+        "failed",
+    ],
+)
 def test_get_save_origin_requests_no_failed_status_override(
     mocker, swh_scheduler, visit_status
 ):
-    """Uneventful visits with failed statuses (failed, not found) are marked as failed
-
-    """
+    """Uneventful visits with failed statuses (failed, not found) are marked as failed"""
     sors = _get_save_origin_requests(
         mocker, swh_scheduler, load_status="uneventful", visit_status=visit_status
     )
@@ -532,15 +551,22 @@ def test_get_visit_info_for_save_request_succeeded(
 
 
 @pytest.mark.django_db
-@pytest.mark.parametrize("load_status", ["eventful", "uneventful",])
+@pytest.mark.parametrize(
+    "load_status",
+    [
+        "eventful",
+        "uneventful",
+    ],
+)
 def test_get_visit_info_incomplete_visit_still_successful(
     mocker, swh_scheduler, load_status
 ):
-    """Incomplete visit information, yet the task is updated partially
-
-    """
+    """Incomplete visit information, yet the task is updated partially"""
     sors = _get_save_origin_requests(
-        mocker, swh_scheduler, load_status=load_status, visit_status=None,
+        mocker,
+        swh_scheduler,
+        load_status=load_status,
+        visit_status=None,
     )
     assert len(sors) == 1
 
@@ -562,8 +588,7 @@ def test_get_visit_info_incomplete_visit_still_successful(
 def test_refresh_in_progress_save_request_statuses(
     mocker, swh_scheduler, api_client, archive_data
 ):
-    """Refresh a pending save origins requests and update if the status changes
-    """
+    """Refresh a pending save origins requests and update if the status changes"""
     date_now = datetime.now(tz=timezone.utc)
     date_pivot = date_now - timedelta(days=30)
     visit_started_date = date_now - timedelta(minutes=1)
@@ -587,9 +612,6 @@ def test_refresh_in_progress_save_request_statuses(
     )
     mock_archive = mocker.patch("swh.web.common.origin_save.archive")
     mock_archive.lookup_origin.return_value = {"url": _origin_url}
-    mock_get_origin_visits = mocker.patch(
-        "swh.web.common.origin_save.get_origin_visits"
-    )
     # create a visit for the save request with status created
     visit_date = datetime.now(tz=timezone.utc).isoformat()
     visit_info = OriginVisitInfo(
@@ -603,7 +625,7 @@ def test_refresh_in_progress_save_request_statuses(
         url="",
         visit=34,
     )
-    mock_get_origin_visits.return_value = [visit_info]
+    mock_archive.origin_visit_find_by_date.return_value = visit_info
 
     # make the scheduler return a running event
     _fill_scheduler_db(
@@ -616,7 +638,11 @@ def test_refresh_in_progress_save_request_statuses(
     # The visit is detected but still running
     sors = refresh_save_origin_request_statuses()
 
-    assert mock_get_origin_visits.called and mock_get_origin_visits.call_count == 1
+    assert (
+        mock_archive.origin_visit_find_by_date.called
+        and mock_archive.origin_visit_find_by_date.call_count == 1
+    )
+
     assert len(sors) == 1
 
     for sor in sors:
@@ -640,13 +666,16 @@ def test_refresh_in_progress_save_request_statuses(
     # (visit date and visit status in final state)
     visit_date = datetime.now(tz=timezone.utc).isoformat()
     visit_info.update({"date": visit_date, "status": VISIT_STATUS_FULL})
-    mock_get_origin_visits.return_value = [visit_info]
+    mock_archive.origin_visit_find_by_date.return_value = visit_info
 
     # Detected entry, this time it should be updated
     sors = refresh_save_origin_request_statuses()
     assert len(sors) == 1
 
-    assert mock_get_origin_visits.called and mock_get_origin_visits.call_count == 1 + 1
+    assert (
+        mock_archive.origin_visit_find_by_date.called
+        and mock_archive.origin_visit_find_by_date.call_count == 1 + 1
+    )
 
     for sor in sors:
         assert iso8601.parse_date(sor["save_request_date"]) >= date_pivot
@@ -663,9 +692,7 @@ def test_refresh_in_progress_save_request_statuses(
 
 @pytest.mark.django_db
 def test_refresh_save_request_statuses(mocker, swh_scheduler, api_client, archive_data):
-    """Refresh filters save origins requests and update if changes
-
-    """
+    """Refresh filters save origins requests and update if changes"""
     date_now = datetime.now(tz=timezone.utc)
     date_pivot = date_now - timedelta(days=30)
     # returned visit status
@@ -687,9 +714,6 @@ def test_refresh_save_request_statuses(mocker, swh_scheduler, api_client, archiv
     )
     mock_archive = mocker.patch("swh.web.common.origin_save.archive")
     mock_archive.lookup_origin.return_value = {"url": _origin_url}
-    mock_get_origin_visits = mocker.patch(
-        "swh.web.common.origin_save.get_origin_visits"
-    )
     # create a visit for the save request with status created
     visit_date = datetime.now(tz=timezone.utc).isoformat()
     visit_info = OriginVisitInfo(
@@ -703,7 +727,7 @@ def test_refresh_save_request_statuses(mocker, swh_scheduler, api_client, archiv
         url="",
         visit=34,
     )
-    mock_get_origin_visits.return_value = [visit_info]
+    mock_archive.origin_visit_find_by_date.return_value = visit_info
 
     # no changes so refresh does detect the entry but does nothing
     sors = refresh_save_origin_request_statuses()
@@ -746,7 +770,7 @@ def test_refresh_save_request_statuses(mocker, swh_scheduler, api_client, archiv
         url="",
         visit=34,
     )
-    mock_get_origin_visits.return_value = [visit_info]
+    mock_archive.origin_visit_find_by_date.return_value = visit_info
 
     # Detected entry, this time it should be updated
     sors = refresh_save_origin_request_statuses()
