@@ -3,6 +3,7 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+import copy
 from datetime import datetime, timezone
 from itertools import chain
 import os
@@ -18,7 +19,7 @@ from swh.scheduler.model import LastVisitStatus, ListedOrigin, OriginVisitStats
 from swh.web.common.utils import reverse
 from swh.web.config import SWH_WEB_SERVER_NAME
 from swh.web.misc.coverage import deposited_origins, legacy_origins, listed_origins
-from swh.web.tests.django_asserts import assert_contains
+from swh.web.tests.django_asserts import assert_contains, assert_not_contains
 from swh.web.tests.utils import check_html_get_response, check_http_get_response
 
 
@@ -33,10 +34,10 @@ def test_coverage_view_no_metrics(client, swh_scheduler):
     )
 
 
-visit_types = ["git", "hg", "svn", "bzr", "svn"]
+visit_types = ["git", "hg", "svn", "bzr", "cvs"]
 
 
-@pytest.fixture(autouse=True)
+@pytest.fixture
 def archive_coverage_data(mocker, swh_scheduler):
     """Generate some sample scheduler metrics and some sample deposits
     that will be consumed by the archive coverage view.
@@ -101,7 +102,8 @@ def archive_coverage_data(mocker, swh_scheduler):
     get_deposits_list.return_value = deposits
 
 
-def test_coverage_view_with_metrics(client):
+def test_coverage_view_with_metrics(client, archive_coverage_data):
+
     # check view gets rendered without errors
     url = reverse("swh-coverage")
     resp = check_html_get_response(
@@ -117,16 +119,19 @@ def test_coverage_view_with_metrics(client):
         logo_url = f'{settings.STATIC_URL}img/logos/{origins["type"].lower()}.png'
         assert_contains(resp, f'src="{logo_url}"')
 
+        origin_visit_types = set()
+
         if "instances" in origins:
             for visit_types_ in origins["instances"].values():
+                origin_visit_types.update(visit_types_.keys())
                 for data in visit_types_.values():
-                    if data["count"]:
+                    if data["count"] and data["search_url"]:
                         assert_contains(resp, f'<a href="{escape(data["search_url"])}"')
         else:
             for search_url in origins["search_urls"].values():
                 assert_contains(resp, f'<a href="{escape(search_url)}"')
 
-    for visit_type in visit_types:
+    for visit_type in origin_visit_types:
         assert_contains(resp, f"<td>{visit_type}</td>")
 
     # check request as in production with cache enabled
@@ -135,7 +140,7 @@ def test_coverage_view_with_metrics(client):
     )
 
 
-def test_coverage_view_with_focus(client):
+def test_coverage_view_with_focus(client, archive_coverage_data):
 
     origins = (
         listed_origins["origins"]
@@ -164,3 +169,93 @@ def test_coverage_view_with_focus(client):
         'class="collapse show"',
         count=len(origins),
     )
+
+
+@pytest.fixture
+def archive_coverage_data_with_non_visited_origins(mocker, swh_scheduler):
+    # mock calls to get nixguix origin counts
+    mock_archive = mocker.patch("swh.web.misc.coverage.archive")
+    mock_archive.lookup_latest_origin_snapshot.return_value = {"id": "some-snapshot"}
+    mock_archive.lookup_snapshot_sizes.return_value = {"release": 30095}
+
+    listers = []
+    for i, origins in enumerate(listed_origins["origins"]):
+        # create one instances for each lister
+        lister = swh_scheduler.get_or_create_lister(
+            origins["type"], f"instance-{origins['type']}"
+        )
+        listers.append(lister)
+
+        if i % 2 == 1 or origins["type"] in ("guix", "nixos"):
+            # do not declare origins for lister with odd index
+            continue
+
+        _origins = []
+        origin_visit_stats = []
+        for j, visit_type in enumerate(visit_types):
+            url = str(uuid.uuid4())
+            _origins.append(
+                ListedOrigin(
+                    lister_id=lister.id,
+                    url=url,
+                    visit_type=visit_type,
+                    extra_loader_arguments={},
+                )
+            )
+            # do not declare visit for visit type with even index
+            if j % 2 != 0:
+                now = datetime.now(tz=timezone.utc)
+                origin_visit_stats.append(
+                    OriginVisitStats(
+                        url=url,
+                        visit_type=visit_type,
+                        last_successful=now,
+                        last_visit=now,
+                        last_visit_status=LastVisitStatus.successful,
+                        last_snapshot=os.urandom(20),
+                    )
+                )
+        # send origins data to scheduler
+        swh_scheduler.record_listed_origins(_origins)
+        swh_scheduler.origin_visit_stats_upsert(origin_visit_stats)
+
+    # compute scheduler metrics
+    swh_scheduler.update_metrics()
+
+    # set deposit origins as empty
+    get_deposits_list = mocker.patch("swh.web.misc.coverage.get_deposits_list")
+    get_deposits_list.return_value = []
+
+
+def test_coverage_view_filter_out_non_visited_origins(
+    client, archive_coverage_data_with_non_visited_origins
+):
+
+    origins = copy.copy(listed_origins)
+
+    # check view gets rendered without errors
+    url = reverse("swh-coverage")
+    resp = check_html_get_response(
+        client,
+        url,
+        status_code=200,
+        template_used="misc/coverage.html",
+        server_name=SWH_WEB_SERVER_NAME,
+    )
+
+    for i, origins in enumerate(origins["origins"]):
+        if origins["type"] in ("guix", "nixos"):
+            continue
+        if i % 2 == 1:
+            # counters for lister with odd index should not be displayed
+            assert_not_contains(resp, f'id="{origins["type"]}"')
+        else:
+            # counters for lister with even index should be displayed
+            assert_contains(resp, f'id="{origins["type"]}"')
+            for j, visit_type in enumerate(visit_types):
+                if j % 2 == 0:
+                    # counter for visit type with even index should be displayed
+                    assert_not_contains(resp, f'id="{origins["type"]}-{visit_type}"')
+                else:
+                    # counter for visit type with odd index should not be displayed
+                    assert_contains(resp, f'id="{origins["type"]}-{visit_type}"')
